stafftools.RhythmicStaff
========================

.. abjad-lineage:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff

.. autoclass:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff

.. only:: html

   Attribute summary
   -----------------

   .. autosummary::

      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.append
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.context_name
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.engraver_consists
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.engraver_removals
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.extend
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.index
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.insert
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_nonsemantic
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_semantic
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_simultaneous
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.lilypond_format
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.name
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.override
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.pop
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.remove
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.reverse
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select_leaves
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select_notes_and_chords
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.set
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.storage_format
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__contains__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__copy__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__delitem__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__eq__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__getitem__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__len__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__mul__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__ne__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__repr__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__rmul__
      ~abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__setitem__

Bases
-----

- :py:class:`stafftools.Staff <abjad.tools.stafftools.Staff.Staff.Staff>`

- :py:class:`contexttools.Context <abjad.tools.contexttools.Context.Context.Context>`

- :py:class:`containertools.Container <abjad.tools.containertools.Container.Container.Container>`

- :py:class:`componenttools.Component <abjad.tools.componenttools.Component.Component.Component>`

- :py:class:`abctools.AbjadObject <abjad.tools.abctools.AbjadObject.AbjadObject.AbjadObject>`

- :py:class:`__builtin__.object <object>`

Read-only properties
--------------------

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.engraver_consists
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.engraver_removals
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_semantic
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.lilypond_format
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.override
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.set
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.storage_format
   :noindex:

Read/write properties
---------------------

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.context_name
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_nonsemantic
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.is_simultaneous
   :noindex:

.. autoattribute:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.name
   :noindex:

Methods
-------

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.append
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.extend
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.index
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.insert
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.pop
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.remove
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.reverse
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select_leaves
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.select_notes_and_chords
   :noindex:

Special methods
---------------

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__contains__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__copy__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__delitem__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__eq__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__getitem__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__len__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__mul__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__ne__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__repr__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__rmul__
   :noindex:

.. automethod:: abjad.tools.stafftools.RhythmicStaff.RhythmicStaff.RhythmicStaff.__setitem__
   :noindex:
